@@ -1,3 +1,10 @@
+const dirTree = require('directory-tree');
+const path = require('path');
+const { generateExamples } = require('./generate-examples');
+
+generateExamples(path.join(__dirname, '../../examples'), path.join(__dirname, '../examples'));
+const examples = dirTree(path.join(__dirname, '../examples'), {extensions:/\.md/});
+
 module.exports = {
   title: 'pywebview',
   description: 'Build GUI for your Python program with JavaScript, HTML, and CSS',
@@ -10,6 +17,7 @@ module.exports = {
       }
     }
   },
+  port: 8082,
   themeConfig: {
     repo: 'r0x0r/pywebview',
     docsDir: 'docs',
@@ -24,7 +32,10 @@ module.exports = {
       { text: 'Blog', link: '/blog/' },
       { text: 'Changelog', link: '/CHANGELOG.md' },
       { text: '2.x', link: 'https://pywebview.flowrl.com/2.4' },
+      { text: '3.x', link: 'https://pywebview.flowrl.com/3.7' },
     ],
+    sidebarDepth: 0,
+    displayAllHeaders: true,
     sidebar: {
       '/guide/': [
           {
@@ -42,45 +53,18 @@ module.exports = {
             '/guide/api',
             '/guide/architecture',
             '/guide/debugging',
+            '/guide/dom',
+            '/guide/faq',
             '/guide/interdomain',
             '/guide/freezing',
             '/guide/security',
-            '/guide/virtualenv',
-            '/guide/renderer',
+            '/guide/web_engine',
           ]
         }
       ],
-      '/examples/': [
-        'cef',
-        'change_url',
-        'css_load',
-        'close_confirm',
-        'debug',
-        'destroy_window',
-        'events',
-        'frameless',
-        'fullscreen',
-        'get_elements',
-        'get_current_url',
-        'hide_window',
-        'html_load',
-        'js_evaluate',
-        'js_api',
-        'loading_animation',
-        'links',
-        'localization',
-        'min_size',
-        'minimize_window',
-        'move_window',
-        'multiple_windows',
-        'open_file_dialog',
-        'open_url',
-        'resize_window',
-        'save_file_dialog',
-        'toggle_fullscreen',
-        'user_agent',
-        'window_title_change'
-      ],
+      '/examples/': examples.children
+        .filter(file => path.parse(file.name).name !== 'README')
+        .map(file => path.parse(file.name).name),
 
       '/contributing/': [
         'development',
@@ -90,4 +74,4 @@ module.exports = {
       ]
     }
   }
-}
\ No newline at end of file
+}
