@@ -1,9 +1,8 @@
-import webview
+"""Set window coordinates and move window after its creation."""
+
 from time import sleep
 
-"""
-This example demonstrates how to move window programmatically
-"""
+import webview
 
 
 def move(window):
@@ -11,11 +10,10 @@ def move(window):
 
     sleep(2)
     window.move(200, 200)
-
+    sleep(1)
     print('Window coordinates are ({0}, {1})'.format(window.x, window.y))
 
 
-
 if __name__ == '__main__':
-    window = webview.create_window('Move window example', html='<h1>Move window</h1>', x=100, y=100)
+    window = webview.create_window('Move window example', html='<h1>Move window</h1>', x=300, y=300)
     webview.start(move, window)
