@@ -1,11 +1,10 @@
-import webview
+"""
+Create a pywebview windows using QT (normally GTK is preferred)
+"""
 
-"""
-This example demonstrates how to create a pywebview windows using QT
-(normally GTK is preferred)
-"""
+import webview
 
 if __name__ == '__main__':
     # Create a non-resizable webview window with 800x600 dimensions
     webview.create_window('Qt Example', 'http://flowrl.com')
-    webview.start(gui='qt')
\ No newline at end of file
+    webview.start(gui='qt')
