@@ -1,9 +1,7 @@
-import webview
-from time import sleep
+"""Resize window."""
 
-"""
-This example demonstrates how to resize window programmatically
-"""
+from time import sleep
+import webview
 
 
 def resize(window):
@@ -13,7 +11,8 @@ def resize(window):
     print('Window size is ({0}, {1})'.format(window.width, window.height))
 
 
-
 if __name__ == '__main__':
-    window = webview.create_window('Resize window example', html='<h1>Resize window</h1>', width=800, height=600)
+    window = webview.create_window(
+        'Resize window example', html='<h1>Resize window</h1>', width=800, height=600
+    )
     webview.start(resize, window)
