@@ -1,19 +1,18 @@
-import webview
-import threading
+"""Change window title every three seconds."""
+
 import time
 
-"""
-This example demonstrates how to change a window title.
-"""
+import webview
 
 
 def change_title(window):
     """changes title every 3 seconds"""
     for i in range(1, 100):
         time.sleep(3)
-        window.set_title('New Title #{}'.format(i))
+        window.title = f'New Title #{i}'
+        print(window.title)
 
 
 if __name__ == '__main__':
     window = webview.create_window('Change title example', 'https://pywebview.flowrl.com/hello')
-    webview.start(change_title, window)
\ No newline at end of file
+    webview.start(change_title, window)
