@@ -1,6 +1,6 @@
-from concurrent.futures.thread import ThreadPoolExecutor
 import webview
-from .util import run_test, assert_js
+
+from .util import assert_js, run_test
 
 
 def test_expose_single():
@@ -55,4 +55,4 @@ def expose_runtime(window):
 
 
 def expose_override(window):
-    assert_js(window, 'get_int', 420)
\ No newline at end of file
+    assert_js(window, 'get_int', 420)
