@@ -1,24 +1,28 @@
-import threading
-import time
-import json
+import logging
 import os
 import sys
-import logging
+import threading
+import time
 import traceback
-import pytest
+from multiprocessing import Queue
 from uuid import uuid4
-from multiprocessing import Process, Queue
+
+import pytest
 
 logger = logging.getLogger('pywebview')
 
 
-def run_test(webview, window, thread_func=None, param=None, start_args={}, no_destroy=False, destroy_delay=0):
+def run_test(
+    webview, window, thread_func=None, param=None, start_args={}, no_destroy=False, destroy_delay=0
+):
     __tracebackhide__ = True
     try:
         queue = Queue()
 
         time.sleep(2)
-        _create_window(webview, window, thread_func, queue, param, start_args, no_destroy, destroy_delay)
+        _create_window(
+            webview, window, thread_func, queue, param, start_args, no_destroy, destroy_delay
+        )
 
         if not queue.empty():
             e = queue.get()
@@ -38,7 +42,9 @@ def assert_js(window, func_name, expected_result, *func_args):
     }}).catch(function() {{
         window.{2} = 'error'
     }})
-    """.format(func_name, func_args, value_id)
+    """.format(
+        func_name, func_args, value_id
+    )
     check_func = 'window.{0}'.format(value_id)
 
     window.evaluate_js(execute_func)
@@ -57,8 +63,9 @@ def assert_js(window, func_name, expected_result, *func_args):
     assert expected_result == result
 
 
-def _create_window(webview, window, thread_func, queue, thread_param, start_args, no_destroy, destroy_delay):
-
+def _create_window(
+    webview, window, thread_func, queue, thread_param, start_args, no_destroy, destroy_delay
+):
     def thread():
         try:
             if thread_func:
@@ -84,7 +91,7 @@ def get_test_name():
     return os.environ.get('PYTEST_CURRENT_TEST').split(':')[-1].split(' ')[0]
 
 
-def _destroy_window(webview, window, delay):
+def _destroy_window(_, window, delay):
     def stop():
         event.wait()
         time.sleep(delay)
@@ -92,6 +99,7 @@ def _destroy_window(webview, window, delay):
 
         if sys.platform == 'darwin':
             from .util_cocoa import mouseMoveRelative
+
             time.sleep(1)
             mouseMoveRelative(1, 1)
 
@@ -101,5 +109,3 @@ def _destroy_window(webview, window, delay):
     t.start()
 
     return event
-
-
